DispatcherDumpEntry

Struct DispatcherDumpEntry 

pub struct DispatcherDumpEntry {
    pub driver: u64,
    pub dispatcher_ptr: u64,
    pub name: String,
    pub scheduler_role: String,
    pub options: u32,
    pub synchronized: bool,
    pub allow_sync_calls: bool,
    pub state: DispatcherState,
    pub destroy_context: String,
    pub destroy_user_initiated: Option<bool>,
    pub debug_stats: DispatcherDebugStats,
    pub queued_tasks: Vec<QueuedTaskDebugInfo>,
}
Structured diagnostic dump entry for a dispatcher in the driver runtime.

Fields

driver: u64

Address of the driver owner of this dispatcher.

dispatcher_ptr: u64

Address of the dispatcher object.

name: String

Name of the dispatcher.

scheduler_role: String

Scheduler role configured for the dispatcher.

options: u32

Options mask the dispatcher was created with.

synchronized: bool

Whether the dispatcher is synchronized.

allow_sync_calls: bool

Whether the dispatcher allows blocking synchronous calls.

state: DispatcherState

Current lifecycle state of the dispatcher.

destroy_context: String

Name of the dispatcher that initiated destruction, if Destroy was called.

destroy_user_initiated: Option<bool>

Whether Destroy was user-initiated (true) or environment-initiated (false).

debug_stats: DispatcherDebugStats

Request and inlining statistics for the dispatcher.

queued_tasks: Vec<QueuedTaskDebugInfo>

Currently queued tasks on the dispatcher.