pub struct NonInlinedStats {
pub allow_sync_calls: u64,
pub parallel_dispatch: u64,
pub task: u64,
pub unknown_thread: u64,
pub reentrant: u64,
pub channel_wait_not_yet_registered: u64,
pub no_thread_migration: u64,
}Expand description
Breakdown of reasons why requests were not inlined by the driver runtime.
Fields
allow_sync_calls: u64Calling from a non-blocking to a blocking (ALLOW_SYNC_CALLS) dispatcher.
parallel_dispatch: u64Another thread was already dispatching a request.
task: u64The request was a task.
unknown_thread: u64The request was queued from an unknown thread.
reentrant: u64The request would have been reentrant.
channel_wait_not_yet_registered: u64Channel wait was not yet registered when the message was received.
no_thread_migration: u64Called into a dispatcher that wasn’t allowed to migrate threads.