ResumeRequesterRegistration

Struct ResumeRequesterRegistration 

pub struct ResumeRequesterRegistration { /* private fields */ }
A registration handle returned by Driver::register_resume_requester. The user MUST call unregister to unregister the resume requester when it is no longer valid.

Implementations

Source

impl ResumeRequesterRegistration

pub fn unregister(self)

Unregisters the resume requester from the runtime and frees the memory associated with it.