pub struct ThreadDumpEntry {
pub koid: u64,
pub name: String,
pub scheduler_role: String,
}Expand description
Structured diagnostic dump entry for a thread spawned by the driver runtime.
Fields
koid: u64Kernel object ID (KOID) of the thread.
name: StringName of the thread.
scheduler_role: StringScheduler role of the thread pool that spawned this thread.