pub struct ResumeRequesterRegistration { /* private fields */ }Expand description
A registration handle returned by Driver::register_resume_requester.
The user MUST call unregister to unregister the resume requester when it is no longer valid.
Implementations
Sourceimpl ResumeRequesterRegistration
impl ResumeRequesterRegistration
Sourcepub fn unregister(self)
pub fn unregister(self)
Unregisters the resume requester from the runtime and frees the memory associated with it.